/**
 * OW2 Specifications
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MapKeyEnumerated.java 5417 2010-03-24 09:04:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package javax.persistence;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import static javax.persistence.EnumType.ORDINAL;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * The MapKeyEnumerated annotation is used to specify the enum type for a map key whose basic type is an enumerated type. The
 * MapKeyEnumerated annotation can be applied to an element collection or relationship of type java.util.Map, in conjunction with
 * the ElementCollection, OneToMany, or ManyToMany annotation. If the map is specified using Java generics, the MapKeyClass
 * annotation and associated type need not be specified; otherwise they must be specified. If the enumerated type is not specified
 * or the MapKeyEnumerated annotation is not used, the enu- merated type is assumed to be ORDINAL.
 * @see <a href="http://jcp.org/en/jsr/detail?id=317">JPA 2.0 specification</a>
 * @author Florent Benoit
 * @since JPA 2.0 version.
 */
@Target({ METHOD, FIELD })
@Retention(RUNTIME)
public @interface MapKeyEnumerated {

    /**
     * (Optional) The type used in mapping a map key enum type.
     **/
    EnumType value() default ORDINAL;
}
